from pdi.Signalling.Event.AbstractEvent import Event


class DispatcherSpeak(Event):
    @classmethod
    def getName(cls) -> str:
        return 'dispatcher.speak'


class DispatcherUnSpeak(Event):
    @classmethod
    def getName(cls) -> str:
        return 'dispatcher.un-speak'



from pdi.Signalling.Event.AbstractEvent import Event


class ExecuteCommand(Event):
    def __init__(self, code: str):
        self.code = code

    @classmethod
    def getName(cls) -> str:
        return 'execute:command'



from pdi.Signalling.Event.AbstractEvent import Event


class InputActive(Event):
    @classmethod
    def getName(cls) -> str:
        return 'input:active'


class InputNotActive(Event):
    @classmethod
    def getName(cls) -> str:
        return 'input:not-active'


class InputVolume(Event):
    def __init__(self, volume: float):
        self.volume = volume

    @classmethod
    def getName(cls) -> str:
        return 'input:volume'



from pdi.Signalling.Event.AbstractEvent import Event


class ServerConnected(Event):
    @classmethod
    def getName(cls) -> str:
        return 'server:connected'


class ServerDisconnected(Event):
    @classmethod
    def getName(cls) -> str:
        return 'server:disconnected'



from pdi.Signalling.Event.AbstractEvent import Event


class Print(Event):
    def __init__(self, text: str):
        self.text = text

    @classmethod
    def getName(cls) -> str:
        return 'print'



from pdi.Signalling.Event.AbstractEvent import Event


class ApplicationInitializing(Event):
    @classmethod
    def getName(cls) -> str:
        return 'application:initializing'


class ApplicationStarted(Event):
    @classmethod
    def getName(cls) -> str:
        return 'application:started'


class HideIndicator(Event):
    @classmethod
    def getName(cls) -> str:
        return 'indicator:hide'


class ShowIndicator(Event):
    @classmethod
    def getName(cls) -> str:
        return 'indicator:show'


class AudioInputDisable(Event):
    @classmethod
    def getName(cls) -> str:
        return 'input:audio:disable'


class AudioInputEnable(Event):
    @classmethod
    def getName(cls) -> str:
        return 'input:audio:enable'


class AudioOutputDisable(Event):
    @classmethod
    def getName(cls) -> str:
        return 'output:audio:disable'


class AudioOutputEnable(Event):
    @classmethod
    def getName(cls) -> str:
        return 'output:audio:enable'


class ErrorWhenExecuteCommand(Event):
    def __init__(self, exception: Exception):
        self.exception = exception

    @classmethod
    def getName(cls) -> str:
        return 'error:execute-command'



from event_dispatcher import SyncEventDispatcher, BaseEventDispatcher

from pdi.Signalling.Event.AbstractEvent import Event


class Signal:
    dispatcher: BaseEventDispatcher

    @classmethod
    def bind(cls, eventName: str, handler: callable):
        if not hasattr(cls, 'dispatcher'):
            cls.dispatcher = SyncEventDispatcher()

        cls.dispatcher.subscribe(eventName, handler)

    @classmethod
    def publish(cls, event: Event):
        cls.dispatcher.dispatch(event.getName(), event)



from pdi.Signalling.Event.AbstractEvent import Event


class Received(Event):
    def __init__(self, command: str):
        self.command = command

    @classmethod
    def getName(cls) -> str:
        return 'command:received'
